@@ -19,9 +19,9 @@ urlpatterns = patterns(
         cache_page(60 * 2)(ChannelFeed(model='Album')),
         name='album_feed'),
     url(r'^album/(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+)$',
-        AlbumDetail.as_view(), name='album_open'),
+        cache_page(60 * 2)(AlbumDetail.as_view()), name='album_open'),
     url(r'^album/(?P<channel__long_slug>[\w\b//-]+)/$',
-        AlbumList.as_view(), name='album_channel'),
+        cache_page(60 * 2)(AlbumList.as_view()), name='album_channel'),
 
     # TAGs
     url(r'^tag/(?P<tag>[\w//-]+)$',
@@ -31,7 +31,7 @@ urlpatterns = patterns(
     url(r'^(?P<long_slug>[\w\b//-]+)/(rss|feed)$',
         cache_page(60 * 2)(ChannelFeed(model='Post')), name='channel_feed'),
     url(r'^(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+)$',
-        PostDetail.as_view(), name='open'),
+        cache_page(60 * 2)(PostDetail.as_view()), name='open'),
     url(r'^(?P<channel__long_slug>[\w\b//-]+)/$',
-        PostList.as_view(), name='channel'),
+        cache_page(60 * 2)(PostList.as_view()), name='channel'),
 )
