@@ -5,12 +5,13 @@ from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import ValidationError
-
 from django.contrib.sites.models import Site
 from django.contrib.sites.managers import CurrentSiteManager
 from django.contrib.redirects.models import Redirect
 from django.utils import timezone
 
+from .managers import PublishableManager
+
 
 class Date(models.Model):
 
@@ -21,19 +22,17 @@ class Date(models.Model):
         abstract = True
 
 
-class PublishableManager(models.Manager):
-    def all_published(self):
-        return super(PublishableManager, self).get_query_set().filter(
-            date_available__lte=timezone.now(), published=True)
-
-
 class Publishable(Date):
 
     user = models.ForeignKey(settings.AUTH_USER_MODEL)
     site = models.ForeignKey(Site, default=1)
     date_available = models.DateTimeField(_(u"Date available"),
-                                          default=timezone.now, null=True)
-    published = models.BooleanField(_(u"Published"), default=False)
+                                          default=timezone.now,
+                                          null=True,
+                                          db_index=True)
+    published = models.BooleanField(_(u"Published"),
+                                    default=False,
+                                    db_index=True)
 
     objects = PublishableManager()
     on_site = CurrentSiteManager()
